@@ -5,11 +5,16 @@ gocept.Lightbox = gocept.Class.extend({
     construct: function(parent_element) {
         this.parent_element = parent_element;
         this.shade = DIV({'id': 'lightbox-shade'})
+        this.header = DIV({'id': 'lightbox-header'});
+        this.closebutton = A({'href': '#', 
+                              'title': 'Close',
+                              'class': 'CloseButton'});
         this.content_box = DIV({'id': 'lightbox'});
-        appendChildNodes(this.parent_element, this.shade, this.content_box);
+        appendChildNodes(this.header, this.closebutton);
+        appendChildNodes(this.parent_element, this.shade, this.header, this.content_box);
+        connect(this.closebutton, 'onclick', this, 'close');
         connect(this.shade, 'onclick', this, 'close');
 
-       
     },
 
     close: function() {
@@ -17,6 +22,7 @@ gocept.Lightbox = gocept.Class.extend({
         disconnectAll('lightbox');
         removeElement('lightbox-shade');
         removeElement('lightbox');
+        removeElement('lightbox-header');
     },
     
     load_url: function(url, query) {
